@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-certificates-extension.c,v 1.2.2.1 2004/02/01 16:26:37 chpe Exp $
+ *  $Id: ephy-certificates-extension.c,v 1.2.2.2 2004/02/21 23:02:03 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -51,7 +51,7 @@ struct EphyCertificatesExtensionPrivate
 };
 
 static void ephy_certificates_extension_class_init	 (EphyCertificatesExtensionClass *klass);
-static void ephy_certificates_extension_iface_init	 (EphyExtensionClass *iface);
+static void ephy_certificates_extension_iface_init	 (EphyExtensionIface *iface);
 static void ephy_certificates_extension_init		 (EphyCertificatesExtension *extension);
 
 static GObjectClass *parent_class = NULL;
@@ -292,7 +292,7 @@ impl_detach_window (EphyExtension *ext,
 }
 
 static void
-ephy_certificates_extension_iface_init (EphyExtensionClass *iface)
+ephy_certificates_extension_iface_init (EphyExtensionIface *iface)
 {
 	iface->attach_window = impl_attach_window;
 	iface->detach_window = impl_detach_window;
