@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tabs-menu-extension.c,v 1.2 2004/01/02 07:12:03 chpe Exp $
+ *  $Id: ephy-tabs-menu-extension.c,v 1.2.2.1 2004/02/21 23:02:08 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,7 +29,7 @@
 #include <epiphany/ephy-extension.h>
 
 static void ephy_tabs_menu_extension_class_init	(EphyTabsMenuExtensionClass *class);
-static void ephy_tabs_menu_extension_iface_init (EphyExtensionClass *iface);
+static void ephy_tabs_menu_extension_iface_init (EphyExtensionIface *iface);
 static void ephy_tabs_menu_extension_init	(EphyTabsMenuExtension *menu);
 
 GObjectClass *tabs_menu_extension_parent_class = NULL;
@@ -114,7 +114,7 @@ ephy_tabs_menu_extension_finalize (GObject *object)
 }
 
 static void
-ephy_tabs_menu_extension_iface_init (EphyExtensionClass *iface)
+ephy_tabs_menu_extension_iface_init (EphyExtensionIface *iface)
 {
 	iface->attach_window = impl_attach_window;
 	iface->detach_window = impl_detach_window;
